@@ -1,5 +1,5 @@
 from cli.tester.dataset_template import generatedClass
 from cli.tester.reporter_template import generatedClass
 from cli.tester.tester_template import generatedClass
-from cli.tester.tester_server_template import generatedClass
+from cli.tester.server_template import generatedClass
 
